django-orsay
************

A toolkit for doing static site generation for sites that are photo heavy. Was 
built to create online photo albums for trips. Most static site generators 
emphasize blogging, this builds on django templating to quickly create a
one-off site like a travel album.

This isn't really ready to be packaged and put up on pypi yet, not sure if it
ever will be. In the meantime, if it is helpful to you, feel free to use it.

.. comment

    Installation
    ============

    .. code-block:: bash

        $ pip install django-orsay


Supports
========

django-orsay has been tested with:

* Django 2.1 using Python 3.7


.. comment 

    Docs & Source
    =============

    Docs: http://django-awl.readthedocs.io/en/latest/

    Source: https://github.com/cltrudeau/django-awl
